@@ -10,20 +10,13 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 def enter_and_leave_function(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        if args:
-            if kwargs:
-                log.info(f"begin to run function {func.__name__},args is {args},kwargs is {kwargs}")
-            else:
-                log.info(f"begin to run function {func.__name__},args is {args}")
-        else:
-            if kwargs:
-                log.info(f"begin to run function {func.__name__},kwargs is {kwargs}")
-            else:
-                log.info(f"begin to run function {func.__name__}")
+        log.info(f"begin to run function {func.__name__}")
         try:
             result = func(*args, **kwargs)
-            log_str=f"finish run function {func.__name__},result type is {type(result)}, and result is {result}"
-            log.info(log_str)
+            if not result:
+                log.warn(f"finish run function {func.__name__},args is {args},kwargs is {kwargs}, but result is None")
+            else:
+                log.info("finish run function {func.__name__}")
             return result
         except Exception as e:
             log.error(f"failed to run functon {func.__name__} error message is : {e}")
